.. MJOLNIR documentation master file, created by
   sphinx-quickstart on Wed Feb 28 17:31:13 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MJOLNIR's documentation!
===================================
Welcome to the documentation page of the MJOLNIR software package developed for data treatment, conversion, and visualization for multiplexing neutron scattering 
spectrometers. With the increased point density measured during a single experiment, flexible and versatile software is needed to deal with this new data. This 
software package tries to both introduce an easy-to-use scripting interface to visualization and treatment while still offering customizable plotting features.

Table of contents
-----------------
Below is an overview of the provided documentation containing everything from physical/mathematical explanations of different concepts through code specific references to 
tutorials and guides on how to make use of MJOLNIR.

.. toctree::
   :maxdepth: 1

   Introduction
   faq
   tutorials
   ShortCuts
   MJOLNIR
   InDepthDocumentation/Documentation
   Optimizations/Optimization   

Sample data can be downloaded `here <https://www.psi.ch/en/media/70468/download?attachment>`_ 

.. table:: Current informations
   :widths: grid
   :align: left

   +------------+
   |  |version| |
   +------------+
   |    |doi|   |
   +------------+
   |   |pypi|   |
   +------------+
   | |coverall| |
   +------------+



.. |coverall| image:: https://coveralls.io/repos/github/MJOLNIRPackage/MJOLNIR/badge.svg?branch=master
    :target: https://coveralls.io/github/MJOLNIRPackage/MJOLNIR?branch=master

.. |pypi| image:: https://img.shields.io/pypi/pyversions/MJOLNIR
    :alt: PyPI - Python Version
    :target: https://pypi.org/project/MJOLNIR/   


.. |doi| image:: https://zenodo.org/badge/117703167.svg
    :target: https://zenodo.org/badge/latestdoi/117703167

.. |version| image:: https://img.shields.io/github/v/release/MJOLNIRPackage/MJOLNIR   
    :alt: GitHub release (latest by date)
    :target: https://github.com/MJOLNIRPackage/MJOLNIR